@@ -1,11 +1,10 @@
 package Net::DNS::DomainName;
-use base qw(Net::DNS::Domain);
 
 #
-# $Id: DomainName.pm 1145 2013-12-17 11:39:45Z willem $
+# $Id: DomainName.pm 1177 2014-03-10 08:33:21Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1145 $)[1];
+$VERSION = (qw$LastChangedRevision: 1177 $)[1];
 
 
 =head1 NAME
@@ -40,11 +39,14 @@ introduced by RFC3597.
 =cut
 
 
+use strict;
+use base qw(Net::DNS::Domain);
+
+use constant OKlc => eval { require 5.010; } || 0;
+
 use integer;
 use Carp;
 
-use constant OKlc => eval { require 5.8.9; } || 0;
-
 
 =head1 METHODS
 
