@@ -1,10 +1,10 @@
 package Net::DNS::RR::TXT;
 
 #
-# $Id: TXT.pm 1147 2013-12-24 15:13:31Z willem $
+# $Id: TXT.pm 1183 2014-04-03 09:08:55Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1147 $)[1];
+$VERSION = (qw$LastChangedRevision: 1183 $)[1];
 
 
 use strict;
@@ -84,12 +84,10 @@ sub rdatastr {			## SpamAssassin workaround, per CPAN RT#81760
 
 package Net::DNS::Text;
 
-my $QQ = _decode_utf8( pack 'C', 34 );
-
 sub quoted_string {
 	my $string = shift->string;
 	return $string if $string =~ /^$|\s|["\$'();@]/;	# should already be quoted
-	join '', $QQ, $string, $QQ;				# quote previously unquoted string
+	join '', '"', $string, '"';				# quote previously unquoted string
 }
 
 1;
